# -*- coding: utf-8 -*-
from liangutil.liangutils import *
from liangutil.mysqlutils import MySQLUtils


class LiangLog:
    """
    LiangLog 记录日志类
    """

    def __init__(self, name, is_print_console=True,is_record_file=False,is_record_db=False, dir_path=None, db_host=None, db_port=None, db_user=None, db_pass=None, db_name=None):
        # name 程序名称
        self.name = name

        # is_print_console 是否打印到控制台
        # is_record_file 是否记录到文件中
        # is_record_db 是否记录到mysql中
        self.is_print_console = is_print_console
        self.is_record_file = is_record_file
        self.is_record_db = is_record_db

        # file_path 如果记录到文件，文件放在哪个目录
        self.dir_path = dir_path

        if is_record_file == True:
            check_path(dir_path)

        if is_record_db == True:
            # 检查数据库连接
            # 前提：保证数据库中，有一个名为program_logs表
            # 字段名          类型      长度
            # datetime       varchar  32
            # level          varchar  32
            # name           varchar  32
            # content        varchar  255
            self.mysql = MySQLUtils(db_host, db_port, db_user, db_pass, db_name)

            if self.mysql.check_table_exist("program_logs") == False:
                raise Exception("program_logs 数据表不存在")


    def print_log(self, level, content):
        """打印日志到控制台

        Args:
            level(str): 等级(WARNING, INFO , ERROR)
            content(str): 日志信息

        """
        formatted_log = "{} EXCEPTION: {}".format(code_location(depth=-4),content)
        log = f"{level} {get_nowdatetime()} {formatted_log}"
        print(log)



    def record_log_to_file(self,level, content):
        """将日志记录到文件

        Args:
            level(str): 等级(WARNING, INFO , ERROR)
            content(str): 日志信息

        """
        now = datetime.datetime.now(pytz.timezone('Asia/Shanghai'))
        file_path = os.path.join(
            self.dir_path,
            f"{self.name}_logs",
            get_nowdate(now),
            level + get_nowtime(now) + ".log",
        )
        check_path(file_path)
        with open(file_path, "a", encoding="utf-8") as f:
            formatted_log = "{} EXCEPTION: {}".format(code_location(depth=-4), content)
            log = f"{level} {get_nowdatetime()} {formatted_log}"
            f.write(log+"\n")


    def record_log_to_db(self, level, content):
        """将日志记录到mysql

        Args:
            level(str): 等级(WARNING, INFO , ERROR)
            content(str): 日志信息

        """
        formatted_log = "{} EXCEPTION: {}".format(code_location(depth=-4), content)
        self.mysql.insert_data("program_logs", {"datetime":get_nowdatetime(), "level":level, "name":self.name, "content":formatted_log})


    def record_log(self, level, content):
        """记录日志总方法(推荐使用)

        Args:
            level(str): 等级(WARNING, INFO , ERROR)
            content(str): 日志信息

        """
        if self.is_print_console:
            self.print_log(level, content)
        if self.is_record_file:
            self.record_log_to_file(level, content)
        if self.is_record_db:
            self.record_log_to_db(level, content)



# -*- coding: utf-8 -*-
import os
import platform
import random
import time
import requests
import wget
import shutil


from func_timeout import func_set_timeout, FunctionTimedOut
from urllib.parse import urlparse
from selenium.webdriver.chrome.options import Options
from selenium import webdriver

from liangutil.liangutils import *

"""
requestutils 中封装了爬虫的类以及方法
"""

# 封装requests请求
class RequestUtils:
    """
    RequestUtils 基于 requests 库进行的封装
    """

    def __init__(self, timeout:int, is_ssl_verify: bool, is_choice_agent:bool = True, proxies=None, proxy_host=None):
        """
        初始化 RequestUtils

        Args:
            timeout(int): 请求超时时间
            is_ssl_verify(bool): 是否验证 SSL 证书
            is_choice_agent(bool): 是否随机 USER-AGENT
            proxies(dict): 代理字典
            proxy_host(str): 代理
        """
        self.timeout = timeout # 请求超时时间
        self.is_ssl_verify = is_ssl_verify # 是否验证SSL证书
        self.is_choice_agent = is_choice_agent # 是否随机AGENT

        # 该参数代理是为了需要用固定ip的爬虫
        self.proxies = proxies   # {'http': 'http://xxx', 'https': 'https://xxx'}

        self.proxy_host = (proxy_host if "://" in proxy_host else "socks5://" + proxy_host) if proxy_host and isinstance(proxy_host,str) else None

    def get_header(self,is_choice_agent=False):
        """获得 USER-AGENT

        Args:
            is_choice_agent(bool): 是否随机 USER-AGENT

        Returns:
            str: USER-AGENT

        """
        header = {
            # "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
            "Accept":"*/*",
            "Accept-Language": "zh-CN,zh;q=0.9",
            "Cache-Control": "max-age=0",
            "Accept-Encoding": "gzip, deflate",  # 使用gzip压缩传输数据让访问更快
            "User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.122 Safari/537.36",
            }
        if is_choice_agent == True:
            chrome_version = "Chrome/{}.0.{}.{}".format(random.randint(55, 82), random.randint(0, 4000),
                                                        random.randint(0, 150))
            os_type = ["(Windows NT 6.0; U; tr; rv:1.8.1)",
                       "(Windows NT 6.1; Win64; x64)"
                       "(Windows NT 6.1; WOW64)",
                       "(Windows NT 10.0; WOW64)",
                       "(X11; Linux x86_64)",
                       "(X11; Linux x86_64; rv:2.0b4)",
                       "(X11; U; FreeBSD x86_64; en-US)",
                       "(X11; Ubuntu; Linux x86_64; rv:24.0)"
                       "(Macintosh; Intel Mac OS X 10_12_6)",
                       "(Macintosh; U; Intel Mac OS X 10_12_6; en-us)",
                       "(Macintosh; U; Intel Mac OS X 10_12_6; ja-jp)",
                       ]
            browser_type = ["Mozilla/5.0",
                            ]
            ua = " ".join([random.choice(browser_type), random.choice(os_type), "AppleWebKit/537.36",
                           "(KHTML, like Gecko)", chrome_version, "Safari/537.36"])
            header["User-Agent"] = ua
        return header


    def get(self, url, headers="", retry_count=3, is_response_json=False, time_sleep=1, proxies=None):
        """Get 请求

        Args:
            url(str): 请求的url
            headers(str): 请求头
            retry_count(int): 重试次数
            is_response_json(bool): 返回的是否是json
            time_sleep(int): 请求失败后的停止时间
            proxies(dict): 代理

        Returns:
            dict: {"error": "状态码/异常", "content": "网页源码/json","url": "请求的url"}

        """
        header = headers if headers else self.get_header(self.is_choice_agent)
        status_code = 200
        while retry_count > 0:
            retry_count = retry_count - 1
            try:
                if proxies == None and self.proxies == None:
                    resp = requests.get(url,headers=header, timeout=self.timeout, verify=self.is_ssl_verify)
                elif proxies != None:
                    resp = requests.get(url, headers=header, proxies=proxies,timeout=self.timeout, verify=self.is_ssl_verify)
                else:
                    resp = requests.get(url, headers=header, proxies=self.proxies, timeout=self.timeout,verify=self.is_ssl_verify)
                if resp.status_code == 200:
                    return {"error":"",
                            "content":resp.json() if is_response_json else resp.text,
                            "url":resp.url}
                else:
                    status_code = resp.status_code
                    time.sleep(time_sleep)


            except Exception as e:
                return {"error": e,
                        "content": "",
                        "url": url}

        return {"error": status_code,
                "content": "",
                "url": url}


    def post(self, url, headers="", data=None, retry_count=3, is_response_json=False, time_sleep=1, proxies=None):
        """Post 请求

        Args:
            url(str): 请求的url
            headers(str): 请求头
            data(dict): payload
            retry_count(int): 重试次数
            is_response_json(bool): 返回的是否是json
            time_sleep(int): 请求失败后的停止时间
            proxies(dict): 代理

        Returns:
            dict: {"error": "状态码/异常", "content": "网页源码/json","url": "请求的url"}

        """
        header = headers if headers else self.get_header(self.is_choice_agent)
        status_code = 200
        while retry_count > 0:
            retry_count = retry_count - 1
            try:
                if proxies == None and self.proxies == None:
                    resp = requests.post(url,headers=header, data=data, timeout=self.timeout, verify=self.is_ssl_verify)
                elif proxies != None:
                    resp = requests.post(url, headers=header, data=data, proxies=proxies,timeout=self.timeout, verify=self.is_ssl_verify)
                else:
                    resp = requests.post(url, headers=header, data=data, proxies=self.proxies, timeout=self.timeout,verify=self.is_ssl_verify)
                if resp.status_code == 200:
                    return {"error":"",
                            "content":resp.json() if is_response_json else resp.text,
                            "url":resp.url}
                else:
                    status_code = resp.status_code
                    time.sleep(time_sleep)


            except Exception as e:
                return {"error": e,
                        "content": "",
                        "url": url}

        return {"error": status_code,
                "content": "",
                "url": url}


    def file_download_once(self, url, file=""):
        """从指定URL下载单个文件的方法

        Args:
            url(str): url
            file(str): 文件名

        Returns:
            True/False
        """
        if file:
            wget.download(url, file)
            return True
        else:
            if self.proxies:
                return requests.get(url, headers=self.get_header(), proxies=self.proxies, stream=True,
                                    timeout=self.timeout)  # stream=True
            else:
                return requests.get(url, headers=self.get_header(), stream=True, timeout=self.timeout)  # stream=True


    def file_download_github(self, github_author, github_project, file_path):
        """下载代码仓库

        Args:
            github_author(str):项目作者
            github_project(str):项目名称
            file_path(str):存放到那里

        Returns:
            bool: True/False
        """
        if self.proxy_host:
            status = os.system("cd " + file_path + " && git config --global http.proxy " + \
                               self.proxy_host + " && git config --global https.proxy " + \
                               self.proxy_host + " && git clone https://github.com/" + github_author + "/" + github_project + ".git")
        else:
            status = os.system("cd " + file_path + " && git config --global --unset http.proxy " + \
                               " && git config --global --unset https.proxy " + \
                               " && git clone https://github.com/" + github_author + "/" + github_project + ".git")
        if status == 0:
            return True
        return False

    def file_download(self, url="", file_path="", file_name="", is_zip_extract=False, retry=3, is_wget=False,
                      github_author="", github_project=""):
        """下载文件主方法(推荐调用)

        Args:
            url(str): url
            file_path(str): 文件存放在哪里
            file_name(str): 文件名称
            is_zip_extract(bool): 是否解压
            retry(int): 重试次数
            is_wget(bool): 是否用wget
            github_author(str): 项目作者
            github_project(str): 项目名称

        Returns:
            bool: True/False
        """
        file_name = os.path.basename(urlparse(url).path) if file_name == "" else file_name
        file_path = os.getcwd() if file_path == "" else file_path

        try:
            if is_wget:
                while retry > 0:
                    try:
                        print("DOWNLOAD %s from %s %s" % (file_name, url, retry))
                        if os.path.exists(os.path.join(file_path, file_name)):
                            os.remove(os.path.join(file_path, file_name))
                        if self.file_download_once(url=url, file=os.path.join(file_path, file_name)):
                            # 解压文件
                            if is_zip_extract == True:
                                uncompress(src_file=os.path.join(file_path, file_name), dest_dir_path=file_path)
                            return True
                    except Exception as e:
                        print("[DOWNLOAD ERROR] %s error:%s" % (url, repr(e)))
                    retry = retry - 1

            elif github_author:
                while retry > 0:
                    try:
                        src = str(github_author + github_project)
                        print("DOWNLOAD github from %s %s" % (src, retry))
                        if os.path.exists(os.path.join(file_path, github_project)):
                            shutil.rmtree(os.path.join(file_path, github_project))
                        if self.file_download_github(github_author=github_author, github_project=github_project, file_path=file_path):
                            return True
                    except Exception as e:
                        print("[DOWNLOAD ERROR] %s error:%s" % (url, repr(e)))
                    retry = retry - 1

            else:
                while retry > 0:
                    try:
                        print("DOWNLOAD %s from %s %s" % (file_name, url, retry))

                        r = self.file_download_once(url=url)
                        if r.status_code == 200:
                            with open(os.path.join(file_path, file_name), 'wb') as f:
                                shutil.copyfileobj(r.raw, f) if r.headers[
                                                                    "content-type"] == "application/x-zip-compressed" else f.write(
                                    r.content)
                            if is_zip_extract == True:
                                uncompress(src_file=os.path.join(file_path, file_name), des_dir_path=file_path)
                            return True
                        else:
                            print(r.status_code)
                    except Exception as e:
                        print("[DOWNLOAD ERROR] %s error:%s" % (url, repr(e)))
                    retry = retry - 1

        except Exception as e:
            print(repr(e))
        return False



# https://selenium-python.readthedocs.io/page-objects.html
# https://www.selenium.dev/zh-cn/documentation/
# 封装 selenium
class ChromeUtils:
    """
    ChromeUtils 基于 selenium 库进行的封装
    """
    def __init__(self, timeout: int, is_ssl_verify: bool=False, is_chrome_headless:bool = False, is_undetected_chromedriver:bool = False, proxy=None):
        self.timeout = timeout  # 请求超时时间
        self.is_ssl_verify = is_ssl_verify  # 是否验证SSL证书
        self.is_chrome_headless = is_chrome_headless # Linux下 is_chrome_headless为True
        self.is_undetected_chromedriver = is_undetected_chromedriver

        # 该参数代理是为了需要用固定ip的爬虫
        self.proxy = proxy # http://xxxxxx
        self.driver = self.get_chrome_driver(proxy)



    def get_chrome_driver(self, proxy=None):
        """获得一个chrome驱动

        Args:
            proxy(str): 代理

        Returns:
            chrome驱动

        """
        chrome_options = Options()

        if proxy != None:
            chrome_options.add_argument("--proxy-server="+proxy)
        elif self.proxy != None:
            chrome_options.add_argument("--proxy-server="+self.proxy)
        chrome_options.add_argument("-window-size=1920,1080") # 设置浏览器窗口的大小为1920x1080像素
        chrome_options.add_argument('--ignore-certificate-errors') # 忽略证书错误
        chrome_options.add_argument('--disable-gpu') # 禁用 GPU 硬件加速
        # chrome_options.add_argument('--incognito') #无痕模式 浏览器不会记录任何浏览历史或者cookie。
        # 禁止使用 /dev/shm。在某些系统中，Chrome 使用 /dev/shm 临时文件系统来共享数据，
        # 但在 Docker 或某些特定配置的系统中，这个文件系统可能会不够用，导致 Chrome 崩溃。
        # 这个选项可以让 Chrome 使用其它方式来共享数据，避免崩溃。
        chrome_options.add_argument('--disable-dev-shm-usage')
        chrome_options.add_argument('--hide-scrollbars') # 隐藏滚动条
        chrome_options.add_argument('--disable-plugins') # 禁用插件
        # chrome_options.add_argument('blink-settings=imagesEnabled=false') #不加载图片, 提升速度
        # 禁用沙箱。沙箱是 Chrome 用来隔离网页进程的一种安全机制，但在某些情况下，例如在 Docker 中运行 Chrome，沙箱可能会导致问题。这个选项可以禁用沙箱。
        chrome_options.add_argument('--no-sandbox')
        if self.is_chrome_headless:
            chrome_options.add_argument('--headless')
        if platform.system() == "Linux":
            chrome_options.add_argument('--headless')
            # 单进程模式。Chrome 默认会为每个标签页或插件启动一个新的进程，
            # 但在某些情况下，例如内存有限，可能希望所有的标签页都在一个进程中运行。这个选项可以让 Chrome 在单进程模式下运行。
            chrome_options.add_argument('--single-process')
        # undetected_chromedriver 是一个第三方库
        # 它可以规避某些网站对 selenium 的检测，使得你的自动化脚本更不容易被网站识别出来。
        # if self.is_undetected_chromedriver:
        #     import undetected_chromedriver as uc  # from session not created: This version of ChromeDriver only supports Chrome version 108
        #     driver = uc.Chrome(options=chrome_options)
        # else:
        #     driver = webdriver.Chrome(options=chrome_options)
        driver = webdriver.Chrome(options=chrome_options)
        driver.set_page_load_timeout(self.timeout) # 设置页面加载超时时间
        driver.set_script_timeout(self.timeout) # 设置脚本执行超时时间。

        # 隐藏浏览器特征
        with open('./stealth.min.js') as f:
            js = f.read()
        driver.execute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument", {
            "source": js
        })

        # 反屏蔽
        driver.execute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument", {
            "source": "Object.defineProperty(navigator, 'webdriver', {get: () => undefined})"
        })

        return driver




    def refresh_chrome(self):
        """重启浏览器

        Returns:
            bool: 重启成功返回True，否则返回False

        """
        retry_time = 3
        time_sleep = 10
        error = ""
        while retry_time:
            try:
                if self.driver:
                    self.driver.quit()
                self.driver = self.get_chrome_driver()
                return True
            except Exception as e:
                retry_time -= 1
                error = str(e)
                time.sleep(time_sleep)
        print("ERROR", str(error))
        return False



    def get_page_source(self, url, time_sleep=0, retry_count=3, proxy=""):
        """获得网页源码

        Args:
            url(str): 请求的url
            time_sleep(int): 页面会在time_sleep时间后获得源码
            retry_count(int): 重试次数，针对<html><head></head><body></body></html>情况
            proxy(str): 代理

        Returns:
            dict: {"error":"异常","content":"网页源码","url":"请求的url"}

        """

        # proxy = http://xxxx
        if proxy != "":
            if not self.driver is None:
                self.driver.quit()
            self.driver = self.get_chrome_driver(proxy)

        print(f"{get_nowdatetime()} Get {url}")


        while retry_count:
            retry_count -= 1
            if self.driver is None:
                return {"error":"ZWChrome 的 driver 为空",
                        "content":"",
                        "url":url}
            try:
                self.driver.get(url)

            except Exception as e:
                if str(e).startswith("Message: timeout:") and self.driver.page_source:
                    return {"error": "",
                            "content": self.driver.page_source,
                            "url": self.driver.current_url}

                if not self.refresh_chrome():
                    return {"error": "重启chrome失败","content": "","url": url}

                try:
                    self.driver.get(url)
                except Exception as e:
                    self.driver.execute("window.stop()")
                    return {"error":e,
                            "content":"",
                            "url":url}
            time.sleep(time_sleep)
            text = self.driver.page_source
            if text == "<html><head></head><body></body></html>":
                continue
            if text:
                return {"error": "",
                        "content": text,
                        "url": self.driver.current_url}
            else:
                return {"error": "没有获得 page_source",
                        "content": "",
                        "url": self.driver.current_url}



    def close(self):
        """关闭Chrome驱动

        """
        if self.driver is not None:
            self.driver.quit()
            self.driver = None



# -*- coding: utf-8 -*-
import pymysql

from liangutil.liangutils import print_log



class MySQLUtils:
    """
    MySQLUtils 基于 pymysql 库进行封装
    """
    def __init__(self, host, port, username, password, database):
        self.conn = pymysql.connect(host=host,port=port, user=username, password=password, database=database)


    def check_table_exist(self, table_name):
        """根据表名检查表是否存在

        Args:
            table_name(str):表名

        Returns:
            存在返回True，否则返回False

        """
        cursor = self.conn.cursor()

        sql = "show tables like '{}'".format(table_name)
        cursor.execute(sql)
        result = cursor.fetchone()
        if result:
            cursor.close()
            return True
        else:
            cursor.close()
            return False


    def insert_data(self, table_name, data: dict):
        """插入一条数据

        Args:
            table_name(str):表名
            data(dict):要插入的数据，以字段名为键，字段值为值。

        Returns:
            插入成功返回"True"

        """
        cursor = self.conn.cursor()
        # 构建 SQL 插入语句
        columns = ', '.join(data.keys())
        values = ', '.join(['%s'] * len(data))
        sql = f"insert into {table_name} ({columns}) values ({values})"
        cursor.execute(sql, tuple(data.values()))
        self.conn.commit()
        cursor.close()
        return "True"



    def insert_datas(self, table_name, data_list: list):
        """插入一条数据

        Args:
            table_name(str):表名
            data(list):要插入的数据列表，以字段名为键，字段值为值。

        Returns:
            插入成功返回"True"

        """

        cursor = self.conn.cursor()
        columns = ', '.join(data_list[0].keys())  # 假设所有字典的键相同
        values_template = ', '.join(['%s'] * len(data_list[0]))
        # 构建 SQL 批量插入语句
        sql = f"insert into {table_name} ({columns}) values ({values_template})"
        # 构建数据列表的值元组
        values_tuples = [tuple(d.values()) for d in data_list]
        cursor.executemany(sql, values_tuples)
        self.conn.commit()
        cursor.close()
        return "True"



    def query_data(self, table_name, columns=[], condition=None):
        """随机查询单条数据

        Args:
            table_name(str):表名
            columns(list): 要查询的列名列表，如果为[]，则查询所有列
            condition(str): 查询条件

        Returns:
            查询结果

        """
        cursor = self.conn.cursor()
        if len(columns) == 0:
            columns_str = "*"
        else:
            columns_str = ', '.join(columns)
        sql = f"SELECT {columns_str} FROM {table_name}"
        if condition:
            sql += f" WHERE {condition} order by rand() limit 1"
        cursor.execute(sql)
        result = cursor.fetchone()
        cursor.close()
        return result

    def query_datas(self, table_name, columns=None, condition=None):
        """查询数据

        Args:
            table_name(str):表名
            columns(list): 要查询的列名列表，如果为[]，则查询所有列
            condition(str): 查询条件

        Returns:
            查询结果(元组)，每条记录为一个元组

        """
        cursor = self.conn.cursor()
        if columns is None:
            columns = []
        columns_str = "*" if len(columns) == 0 else ', '.join(columns)
        sql = f"SELECT {columns_str} FROM {table_name}"
        if condition:
            sql += f" WHERE {condition}"
        cursor.execute(sql)
        result = cursor.fetchall()
        cursor.close()
        return result

    def query_datas_dict_list(self, table_name, columns=None, condition=None):
        """查询数据

        Args:
            table_name(str):表名
            columns(list): 要查询的列名列表，如果为[]，则查询所有列
            condition(str): 查询条件

        Returns:
            查询结果 [{},{},{}]

        """
        cursor = self.conn.cursor()
        if columns is None:
            columns = []
        columns_str = "*" if len(columns) == 0 else ', '.join(columns)
        sql = f"SELECT {columns_str} FROM {table_name}"
        if condition:
            sql += f" WHERE {condition}"
        cursor.execute(sql)
        result = self.fetchall_to_dict_list(cursor)
        cursor.close()
        return result


    def exists_data(self, table_name, columns=None, condition=None):
        """是否存在该数据

        Args:
            table_name(str):表名
            columns(list): 要查询的列名列表，如果为[]，则查询所有列
            condition(str): 查询条件

        Returns:
            存在True，否则False

        """
        if columns is None:
            columns = []
        if condition is None:
            print("WARNING", " You didn't pass in a condition parameter, so it's pointless")
        datas = self.query_data(table_name, columns, condition)
        if datas != None:
            return len(datas) > 0
        return False

    def update_datas(self, table_name, data, condition=None):
        """更新数据

        Args:
            table_name(str): 表名
            data(dict): 要更新的数据，以字段名为键，字段值为值。
            condition(str): 更新条件

        Returns:
            更新成功返回 "True"，失败返回异常
        """
        cursor = self.conn.cursor()
        # 构建 SQL 更新语句
        set_columns = ', '.join([f"{column} = %s" for column in data.keys()])
        sql = f"UPDATE {table_name} SET {set_columns}"
        if condition:
            sql += f" WHERE {condition}"
        # 执行 SQL 更新
        cursor.execute(sql, tuple(data.values()))
        # 提交事务
        self.conn.commit()
        cursor.close()
        return "True"

    def fetchall_to_dict_list(self, cursor):
        """将pymysql的fetchall查询结果转换为装有dict类型的列表

        Args:
            cursor: pymysql游标对象

        Returns:
            装有字典类型的列表
        """
        column_names = [desc[0] for desc in cursor.description]
        return [dict(zip(column_names, row)) for row in cursor.fetchall()]



# -*- coding: utf-8 -*-
import redis


class RedisUtils:
    """
    RedisUtils 基于 redis 库进行封装
    """
    def __init__(self, host, port, dbnum, password):
        self.redis = redis.Redis(host=host, port=port, db=dbnum, password=password)


    def enqueue_message(self,stream_name, data):
        """向Redis流插入数据

        Args:
            stream_name(str): 流名称
            data(*):数据

        """
        self.redis.xadd(stream_name, data)

    def close(self):
        self.redis.close()



# -*- coding: utf-8 -*-
import json

from minio import Minio

from liangutil.redisutils import RedisUtils


class MinIOUtils:

    def __init__(self, ip_port, access_key, secret_key):

        self.minioClient = Minio(ip_port, access_key,
                            secret_key, secure=False)


    # 获取MinIO中的config配置文件
    def get_jsonfile(self, bucket_name, filepath) -> dict:
        """获取MinIO中的json文件

        Args:
            bucket_name(str):桶名称
            filepath(str):文件路径

        Returns:
            dict

        """
        json_file = self.minioClient.get_object(bucket_name,filepath)
        return json.loads(json_file.data.decode("utf-8"))


    def upload_file_to_minio(self, bucket_name: str, file_path: str, current_path: str):
        """将文件上传至MinIO

        Args:
            bucket_name(str): 桶名称
            file_path(str): 上传到MinIO的文件路径
            current_path(str): 文件当前相对路径

        """

        try:
            self.minioClient.fput_object(bucket_name, file_path, current_path)
            print(current_path, "上传成功, MinIO的路径：", f"{bucket_name}/{file_path}")
        except Exception as e:
            print("出错了", e)


